@@ -14,6 +14,13 @@ legend_prepare <- function(gp, gt, scaleFactor) {
 	if (!gt$legend.show) gt$legend.config <- ""
 	if (!gt$legend.hist.show) gt$legend.config <- setdiff(gt$legend.config, "fill_hist")
 	
+	if (is.null(names(gt$legend.is.portrait))) {
+		legend.is.portrait <- rep(gt$legend.is.portrait, length.out=length(varnames2))
+		names(legend.is.portrait) <- varnames2
+	} else {
+		legend.is.portrait <- gt$legend.is.portrait
+	}
+	
 	
 	legelem <- mapply(function(v3, v2, i) {
 		if (!is.na(i) && v3 %in% gt$legend.config) {
@@ -23,7 +30,7 @@ legend_prepare <- function(gp, gt, scaleFactor) {
 			legend.misc <- paste(v2, "legend.misc", sep=".")
 			if (is.na(g[[legend.labels]][1])) NULL else {
 				c(list(legend.type=v3,
-					   legend.is.portrait=gt$legend.is.portrait[v2],
+					   legend.is.portrait=legend.is.portrait[v2],
 					   legend.labels=g[[legend.labels]],
 					   legend.palette=g[[legend.palette]]),
 				  g[[legend.misc]])
