@@ -1,14 +1,16 @@
 process_fill_vector <- function(x, g, gt, tiny) {
 	fill.values <- x
+	textNA <- ifelse(any(is.na(fill.values)), g$textNA, NA)
 	
 	x[tiny] <- NA
 	
+	
 	if (is.factor(x)) {
 		palette <- if (is.null(g$palette)) ifelse(nlevels(x)>8, "Set3", "Dark2") else g$palette
 		colsLeg <- cat2pal(x,
 						   palette = palette,
 						   colorNA = g$colorNA,
-						   legend.NA.text = g$textNA,
+						   legend.NA.text = textNA,
 						   max_levels=g$max.categories)
 		fill.breaks <- NA
 	} else {
@@ -18,8 +20,9 @@ process_fill_vector <- function(x, g, gt, tiny) {
 						   auto.palette.mapping = g$auto.palette.mapping,
 						   contrast = g$contrast, legend.labels=g$labels,
 						   colorNA=g$colorNA, 
+						   legend.scientific=gt$legend.scientific,
 						   legend.digits=gt$legend.digits,
-						   legend.NA.text = g$textNA)
+						   legend.NA.text = textNA)
 		fill.breaks <- colsLeg[[4]]
 	}
 	fill <- colsLeg[[1]]
@@ -43,6 +46,7 @@ process_fill_vector <- function(x, g, gt, tiny) {
 
 
 process_fill <- function(data, g, gb, gt, gby) {
+	
 	npol <- nrow(data)
 	by <- data$GROUP_BY
 	areas <- data$SHAPE_AREAS
@@ -67,7 +71,7 @@ process_fill <- function(data, g, gb, gt, gby) {
 	nx <- max(nx, nlevels(by))
 		
 	# return if data is matrix of color values
-	if (is.matrix(dt)) return(list(fill=dt, xfill=rep(NA, nx)))
+	if (is.matrix(dt)) return(list(fill=dt, fill.alpha=g$alpha, xfill=rep(NA, nx)))
 	tiny <- areas_prop < g$thres.poly
 	if (all(tiny)) warning("all relative area sizes are below thres.poly")
 	if (is.list(dt)) {
@@ -95,8 +99,9 @@ process_fill <- function(data, g, gb, gt, gby) {
 		fill.values <- lapply(split(dt, rep(1:nx, each=npol)), function(d)d[!tiny])
 	}
 	list(fill=fill,
+		 fill.alpha=g$alpha,
 		 fill.legend.labels=fill.legend.labels,
 		 fill.legend.palette=fill.legend.palette,
-		 fill.legend.misc=list(values=fill.values, breaks=fill.breaks, lwd=gb$lwd, border.col=gb$col),
+		 fill.legend.misc=list(values=fill.values, breaks=fill.breaks, alpha=g$alpha, lwd=gb$lwd, border.col=gb$col, border.alpha=gb$alpha),
 		 xfill=x)
 }
