@@ -19,6 +19,7 @@ process_line_col_vector <- function(x, g, gt) {
 						   palette = palette,
 						   auto.palette.mapping = g$auto.palette.mapping,
 						   contrast = g$contrast, legend.labels=g$labels,
+						   legend.scientific=gt$legend.scientific,
 						   legend.digits=gt$legend.digits,
 						   legend.NA.text=g$textNA)
 		line.col <- colsLeg[[1]]
@@ -144,14 +145,17 @@ process_lines <- function(data, g, gt, gby) {
 	list(line.col=line.col,
 		 line.lwd=line.lwd,
 		 line.lty=g$lines.lty,
+		 line.alpha=g$lines.alpha,
 		 line.col.legend.labels=line.col.legend.labels,
 		 line.col.legend.palette=line.col.legend.palette,
 		 line.col.legend.misc=list(line.legend.lwd=line.legend.lwd, 
-		 						  line.legend.lty=g$lines.lty),
+		 						  line.legend.lty=g$lines.lty,
+		 						  line.legend.alpha=g$lines.alpha),
 		 line.lwd.legend.labels=line.lwd.legend.labels,
 		 line.lwd.legend.palette=line.lwd.legend.palette,
 		 line.lwd.legend.misc=list(legend.lwds=line.legend.lwds,
-		 						  line.legend.lty=g$lines.lty),
+		 						  line.legend.lty=g$lines.lty,
+		 						  line.legend.alpha=g$lines.alpha),
 		 xline=xcol,
 		 xlinelwd=xlwd)
 
