@@ -1,38 +1,40 @@
 #' Specify the shape object
 #' 
-#' This element specifies the shape object. Also the used projection and covered area (bounding box) can be set.
-#' 
+#' Creates a \code{\link{tmap-element}} that specifies the shape object. Also the projection and covered area (bounding box) can be set. It is possible to use multiple shape objects within one plot (see \code{\link{tmap-element}}).
+#'  
 #' @param shp shape object, which is one of
-#' \itemize{
-#'  \item{"1)"}\code{\link[sp:SpatialPolygonsDataFrame]{SpatialPolygons(DataFrame)}}
-#'  \item{"2)"}\code{\link[sp:SpatialPointsDataFrame]{SpatialPoints(DataFrame)}}
-#'  \item{"3)"}\code{\link[sp:SpatialLinesDataFrame]{SpatialLines(DataFrame)}}
+#' \enumerate{
+#'  \item{\code{\link[sp:SpatialPolygonsDataFrame]{SpatialPolygons(DataFrame)}}}
+#'  \item{\code{\link[sp:SpatialPointsDataFrame]{SpatialPoints(DataFrame)}}}
+#'  \item{\code{\link[sp:SpatialLinesDataFrame]{SpatialLines(DataFrame)}}}
 #' }
-#'For drawing layers \code{\link{tm_fill}} and \code{\link{tm_borders}}, 1 is required. For drawing layer \code{\link{tm_lines}} 3 is required. Layers \code{\link{tm_bubbles}} and \code{\link{tm_text}}, accept any of them. 
-#' @param projection character that determines the projection. Either a \code{PROJ.4} character string (see \url{http://trac.ostm.org/proj/}), of one of the following shortcuts: 
+#'For drawing layers \code{\link{tm_fill}} and \code{\link{tm_borders}}, 1 is required. For drawing layer \code{\link{tm_lines}}, 3 is required. Layers \code{\link{tm_bubbles}} and \code{\link{tm_text}} accept any of them. 
+#' @param projection character that determines the projection. Either a \code{PROJ.4} character string or one of the following shortcuts: 
 #' \describe{
-#'    	\item{\code{"longlat"}}{Not really a projection, but a plot of the longitude-latitude coordinates.} 
-#'    	\item{\code{"wintri"}}{Winkel Tripel (1921). Popular projection that is useful in world maps. It is the standard of world maps made by the National tmgraphic Society. Type: compromise} 
+#'    	\item{\code{"longlat"}}{Not really a projection, but a plot of the longitude-latitude coordinates (WGS84 datum).} 
+#'    	\item{\code{"wintri"}}{Winkel Tripel (1921). Popular projection that is useful in world maps. It is the standard of world maps made by the National Geographic Society. Type: compromise} 
 #'    	\item{\code{"robin"}}{Robinson (1963). Another popular projection for world maps. Type: compromise}
 #'    	\item{\code{"eck4"}}{Eckert IV (1906). Projection useful for world maps. Area sizes are preserved, which makes it particularly useful for truthful choropleths. Type: equal-area}
 #'    	\item{\code{"hd"}}{Hobo-Dyer (2002). Another projection useful for world maps in which area sizes are preserved. Type: equal-area}
 #'    	\item{\code{"gall"}}{Gall (Peters) (1855). Another projection useful for world maps in which area sizes are preserved. Type: equal-area}
 #'    	\item{\code{"merc"}}{Mercator (1569). Projection in which shapes are locally preserved. However, areas close to the poles are inflated. Google Maps uses a close variant of the Mercator. Type: conformal}
+#'    	\item{\code{"utmXX(s)"}}{Universal Transverse Mercator. Set of 60 projections where each projection is a traverse mercator optimized for a 6 degree longitude range. These ranges are called UTM zones. Zone \code{01} covers -180 to -174 degrees (West) and zone \code{60} 174 to 180 east. Replace XX in the character string with the zone number. For southern hemisphere, add \code{"s"}. So, for instance, the Netherlands is \code{"utm31"} and New Zealand is \code{"utm59s"}}
 #'    	\item{\code{"mill"}}{Miller (1942). Projetion based on Mercator, in which poles are displayed. Type: compromise}
 #'    	\item{\code{"eqc0"}}{Equirectangular (120). Projection in which distances along meridians are conserved. The equator is the standard parallel. Also known as Plate Carr\'ee. Type: equidistant}
 #'    	\item{\code{"eqc30"}}{Equirectangular (120). Projection in which distances along meridians are conserved. The latitude of 30 is the standard parallel. Type: equidistant}
 #'    	\item{\code{"eqc45"}}{Equirectangular (120). Projection in which distances along meridians are conserved. The latitude of 45 is the standard parallel. Also known as Gall isographic. Type: equidistant}
 #'    	\item{\code{"rd"}}{Rijksdriehoekstelsel. Triangulation coordinate system used in the Netherlands.}}
 #'    	See \url{http://en.wikipedia.org/wiki/List_of_map_projections} for a overview of projections.
-#'    	By default, the projection is used that is defined in the \code{shp} object itself.
-#' @param xlim limits of the x-axis
-#' @param ylim limits of the y-axis
-#' @param relative boolean that determines whether relative values are used for \code{xlim} and \code{ylim} or absolute. Note: relative values will depend on the current bounding box (bbox) of the first shape object.
-#' @param bbox bounding box, which is a 2x2 matrix that consists absolute \code{xlim} and \code{ylim} values. If specified, it overrides the \code{xlim} and \code{ylim} parameters.
+#'    	See \url{http://trac.osgeo.org/proj/} for the \code{PROJ.4} project home page. An extensive list of \code{PROJ.4} codes can be created with rgdal's \code{\link[rgdal:make_EPSG]{make_EPSG}}.
+#'    	By default, the projection is used that is defined in the \code{shp} object itself, which can be obtained with \code{\link{get_projection}}.
+#' @param xlim limits of the x-axis. These are either absolute or relative (depending on the argument \code{relative}). Alternatively, the argument \code{bbox} can be set to set absolute values.
+#' @param ylim limits of the y-axis. See \code{xlim}.
+#' @param relative boolean that determines whether relative values are used for \code{xlim} and \code{ylim} or absolute. Note: in case multiple shape objects are used within one plot, the relative values will depend on the current bounding box (bbox) of the first shape object.
+#' @param bbox bounding box, which is a 2x2 matrix that consists absolute \code{xlim} and \code{ylim} values. If specified, it overrides both \code{xlim} and \code{ylim}.
 #' @export
+#' @seealso \code{\link{read_shape}} to read ESRI shape files, \code{\link{set_projection}}, \href{../doc/tmap-nutshell.html}{\code{vignette("tmap-nutshell")}} 
 #' @example ../examples/tm_shape.R
 #' @return \code{\link{tmap-element}}
-#' @seealso \code{\link{set_projection}}, \href{../doc/tmap-nutshell.html}{\code{vignette("tmap-nutshell")}}
 tm_shape <- function(shp, 
 					  projection=NULL, 
 					  xlim = NULL,
@@ -49,16 +51,17 @@ tm_shape <- function(shp,
 
 #' Draw polygon borders
 #' 
-#' This layer defines the borders of the polygons. Color, line width and line type can be set.
+#' Creates a \code{\link{tmap-element}} that defines the borders of the polygons. Line color, width, and type can be set.
 #' 
 #' @param col line color
 #' @param lwd line width (see \code{\link[graphics:par]{par}})
 #' @param lty line type (see \code{\link[graphics:par]{par}})
+#' @param alpha transparency number between 0 (totally transparent) and 1 (not transparent). By default, the alpha value of the \code{col} is used (normally 1).
 #' @export
 #' @example ../examples/tm_borders.R
 #' @seealso \href{../doc/tmap-nutshell.html}{\code{vignette("tmap-nutshell")}}
 #' @return \code{\link{tmap-element}}
-tm_borders <- function(col="grey40", lwd=1, lty="solid") {
+tm_borders <- function(col="grey40", lwd=1, lty="solid", alpha=NA) {
 	g <- list(tm_borders=as.list(environment()))
 	class(g) <- "tmap"
 	g
@@ -67,28 +70,31 @@ tm_borders <- function(col="grey40", lwd=1, lty="solid") {
 
 #' Add text labels
 #' 
-#' This layer adds text labels
+#' Creates a \code{\link{tmap-element}} that adds text labels.
 #' 
 #' @param text name of the variable in the shape object that contains the text labels
-#' @param cex relative size of the text labels. Eiter one number, a name of a numeric variable in the shape data that is used to scale the sizes proportionally, or \code{AREA} where the text size is proportional to the the area size of the polygons.
-#' @param root root number to which the font sizes are scaled. Only applicable if \code{cex} is a variable name or \code{"AREA"}. If \code{root=2}, the square root is taken, if \code{root=3} the cube root etc.
-#' @param fontcolor relative size of the text labels
+#' @param cex relative size of the text labels (see note). Eiter one number, a name of a numeric variable in the shape data that is used to scale the sizes proportionally, or the value \code{"AREA"}, where the text size is proportional to the area size of the polygons.
+#' @param root root number to which the font sizes are scaled. Only applicable if \code{cex} is a variable name or \code{"AREA"}. If \code{root=2}, the square root is taken, if \code{root=3}, the cube root etc.
+#' @param fontcolor color of the text labels
 #' @param fontface font face of the text labels
 #' @param fontfamily font family of the text labels
-#' @param case case of the font. Use "upper" to generate upper-case text, "lower" to generate lower-case text, and use \code{NA} to leave the text as is.
+#' @param alpha transparency number between 0 (totally transparent) and 1 (not transparent). By default, the alpha value of the \code{fontcolor} is used (normally 1).
+#' @param case case of the font. Use "upper" to generate upper-case text, "lower" to generate lower-case text, and \code{NA} to leave the text as is.
+#' @param shadow logical that determines whether a shadow is depicted behind the text. The color of the shadow is either white or yellow, depending of the \code{fontcolor}.
 #' @param bg.color background color of the text labels. By default, \code{bg.color=NA}, so no background is drawn.
-#' @param bg.alpha number between 0 and 255 that specifies the transparancy of the text background (0 is totally transparent, 255 is solid background). The default value is 100.
-#' @param cex.lowerbound lowerbound for \code{cex}. Needed to ignore the tiny labels in case \code{cex} is a variable.
-#' @param print.tiny boolean that determines if tiny labels (which size is smaller than \code{cex.lowerbound}) are print at size \code{cex.lowerbound}
-#' @param scale scalar needed in case cex is based 
-#' @param xmod horizontal position modification of the text, relatively where 0 means no modification, and 1 means the total width of the frame. Either a single number for all polygons, or a numeric variable in the shape data specifying a number for each polygon. Together with \code{ymod}, it determines position modification of the text labels. In most coordinate systems (projections), the origin is located at the bottom left, so negative \code{xmod} move the text to the left, and negative \code{ymod} values to the bottom.
+#' @param bg.alpha number between 0 and 1 that specifies the transparancy of the text background (0 is totally transparent, 1 is solid background).
+#' @param cex.lowerbound lowerbound for \code{cex}. Only useful when \code{cex} is not a constant. If \code{print.tiny} is \code{TRUE}, then all text labels which relative text is smaller than \code{cex.lowerbound} are depicted at relative size \code{cex.lowerbound}. If \code{print.tiny} is \code{FALSE}, then text labels are only depicted if their relative sizes are at least \code{cex.lowerbound} (in other words, tiny labels are omitted).
+#' @param print.tiny boolean, see \code{cex.lowerbound}
+#' @param scale text size multiplier, useful in case \code{cex} is variable or \code{"AREA"}.
+#' @param xmod horizontal position modification of the text (relatively): 0 means no modification, and 1 means the total width of the frame. Either a single number for all polygons, or a numeric variable in the shape data specifying a number for each polygon. Together with \code{ymod}, it determines position modification of the text labels. In most coordinate systems (projections), the origin is located at the bottom left, so negative \code{xmod} move the text to the left, and negative \code{ymod} values to the bottom.
 #' @param ymod vertical position modification. See xmod.
+#' @note The absolute fontsize (in points) is determined by the (ROOT) viewport, which may depend on the graphics device.
 #' @export
 #' @example ../examples/tm_text.R
 #' @seealso \href{../doc/tmap-nutshell.html}{\code{vignette("tmap-nutshell")}}
 #' @return \code{\link{tmap-element}}
-tm_text <-  function(text, cex=1, root=3, fontcolor=NA, fontface="plain", fontfamily="sans", case=NA, bg.color=NA, bg.alpha=100, cex.lowerbound=.4, print.tiny=FALSE, scale=1, xmod=0, ymod=0) {
-	g <- list(tm_text=list(text=text, text.cex=cex, root=root, text.fontcolor=fontcolor, text.fontface=fontface, text.fontfamily=fontfamily, text.case=case, text.bg.color=bg.color, text.bg.alpha=bg.alpha,
+tm_text <-  function(text, cex=1, root=3, fontcolor=NA, fontface="plain", fontfamily="sans", alpha=NA, case=NA, shadow=FALSE, bg.color=NA, bg.alpha=NA, cex.lowerbound=.4, print.tiny=FALSE, scale=1, xmod=0, ymod=0) {
+	g <- list(tm_text=list(text=text, text.cex=cex, root=root, text.fontcolor=fontcolor, text.fontface=fontface, text.fontfamily=fontfamily, text.alpha=alpha, text.case=case, text.shadow=shadow, text.bg.color=bg.color, text.bg.alpha=bg.alpha,
 							text.cex.lowerbound=cex.lowerbound, text.print.tiny=print.tiny, text.scale=scale, text.xmod=xmod, text.ymod=ymod))
 	class(g) <- "tmap"
 	g
@@ -97,14 +103,15 @@ tm_text <-  function(text, cex=1, root=3, fontcolor=NA, fontface="plain", fontfa
 
 #' Draw spatial lines
 #' 
-#' This layer draw spatial lines.
+#' Creates a \code{\link{tmap-element}} that draw spatial lines.
 #' 
 #' @param col color of the lines. Either a color value or a data variable name.
 #' @param lwd line width
 #' @param lty line type
+#' @param alpha transparency number between 0 (totally transparent) and 1 (not transparent). By default, the alpha value of the \code{col} is used (normally 1).
 #' @param scale line width multiplier number. 
 #' @param n preferred number of color scale classes. Only applicable when \code{lwd} is the name of a numeric variable.
-#' @param style method to cut the color scale: "fixed", "equal", "pretty", "quantile", "kmeans". Only applicable when \code{lwd} is the name of a numeric variable.
+#' @param style method to cut the color scale: e.g. "fixed", "equal", "pretty", "quantile", or "kmeans". See the details in \code{\link[classInt:classIntervals]{classIntervals}}. Only applicable when \code{lwd} is the name of a numeric variable.
 #' @param breaks in case \code{style=="fixed"}, breaks should be specified
 #' @param palette color palette (see \code{RColorBrewer::display.brewer.all}) for the lines. Only when \code{col} is set to a variable.
 #' @param labels labels of the classes
@@ -117,7 +124,7 @@ tm_text <-  function(text, cex=1, root=3, fontcolor=NA, fontface="plain", fontfa
 #' @seealso \href{../doc/tmap-nutshell.html}{\code{vignette("tmap-nutshell")}}
 #' @example ../examples/tm_lines.R
 #' @return \code{\link{tmap-element}}
-tm_lines <- function(col="red", lwd=1, lty="solid", 
+tm_lines <- function(col="red", lwd=1, lty="solid", alpha=NA,
 					  scale=1,
 					  n = 5, style = "pretty",
 					  breaks = NULL,
@@ -128,7 +135,7 @@ tm_lines <- function(col="red", lwd=1, lty="solid",
 					  max.categories = 12, 
 					  colorNA = "grey65",
 					  textNA = "Missing") {
-	g <- list(tm_lines=list(lines.col=col, lines.lwd=lwd, lines.lty=lty, lines.scale=scale,
+	g <- list(tm_lines=list(lines.col=col, lines.lwd=lwd, lines.lty=lty, lines.alpha=alpha, lines.scale=scale,
 							 n=n, style=style, breaks=breaks, palette=palette, labels=labels,
 							 auto.palette.mapping=auto.palette.mapping,
 							 max.categories=max.categories,
@@ -138,16 +145,17 @@ tm_lines <- function(col="red", lwd=1, lty="solid",
 }
 
 
-#' Draw choropleth
+#' Fill polygons
 #' 
-#' This layer speficies a choropleth. A color palette is mapped to a data variable. By default, a divering color palette is used for numeric variables and a qualitative palette for categorical variables.
+#' Creates a \code{\link{tmap-element}} that fills polygons. Either a fixed color is used, or a color palette is mapped to a data variable. By default, a divering color palette is used for numeric variables and a qualitative palette for categorical variables.
 #' 
-#' @param col either a single color value or a name of the data variable that is contained in \code{shp}. In the latter case, a choropleth is drawn.
+#' @param col either a single color value or the name of a data variable that is contained in \code{shp}. In the latter case, either the data variable contains color values, or values (numeric or categorical) that will be depicted by a color palette (see \code{palette}. In the latter case, a choropleth is drawn.
+#' @param alpha transparency number between 0 (totally transparent) and 1 (not transparent). By default, the alpha value of the \code{col} is used (normally 1).
 #' @param palette palette name. See \code{RColorBrewer::display.brewer.all()} for options. Use a \code{"-"} as prefix to reverse the palette. By default, \code{"RdYlGn"} is taken for numeric variables and \code{"Dark2"} for categorical variables.
 #' @param n preferred number of classes (in case \code{col} is a numeric variable)
 #' @param convert2density boolean that determines whether \code{col} is converted to a density variable. Should be \code{TRUE} when \code{col} consists of absolute numbers. The area size is either approximated from the shape object, or given by the argument \code{area}.
 #' @param area Name of the data variable that contains the area sizes in squared kilometer.
-#' @param style method to cut the color scale (in case \code{col} is a numeric variable): "fixed", "equal", "pretty", "quantile", "kmeans"
+#' @param style method to cut the color scale (in case \code{col} is a numeric variable): e.g. "fixed", "equal", "pretty", "quantile", or "kmeans". See the details in \code{\link[classInt:classIntervals]{classIntervals}}.
 #' @param breaks in case \code{style=="fixed"}, breaks should be specified
 #' @param labels labels of the classes
 #' @param auto.palette.mapping When diverging colour palettes are used (i.e. "RdBu") this method automatically maps colors to values such that the middle colors (mostly white or yellow) are assigned to values of 0, and the two sides of the color palette are assigned to negative respectively positive values.
@@ -160,7 +168,8 @@ tm_lines <- function(col="red", lwd=1, lty="solid",
 #' @example ../examples/tm_fill.R
 #' @seealso \href{../doc/tmap-nutshell.html}{\code{vignette("tmap-nutshell")}}
 #' @return \code{\link{tmap-element}}	
-tm_fill <- function(col="grey90", 
+tm_fill <- function(col="grey85", 
+					alpha=NA,
 						    palette = NULL,
 						    convert2density = FALSE,
 					 		area = NULL,
@@ -171,7 +180,7 @@ tm_fill <- function(col="grey90",
 							auto.palette.mapping = TRUE,
 							contrast = 1,
 					 		max.categories = 12,
-					 		colorNA = "grey65",
+					 		colorNA = "grey60",
 					 		textNA = "Missing",
 							thres.poly = 1e-05) {
 	
@@ -180,18 +189,22 @@ tm_fill <- function(col="grey90",
 	g
 }	
 
-#' Draw bubble map
+#' Draw bubbles
 #' 
-#' This layer speficies a bubble map. Both colors and sizes of the bubbles can be mapped to data variables. 
+#' Creates a \code{\link{tmap-element}} that draws bubbles. Both colors and sizes of the bubbles can be mapped to data variables. 
 #' 
 #' @param size \code{shp} data variable that determines the bubble sizes. Multiple variable names create small multiples
 #' @param col color(s) of the bubble. Either a color (vector), or categorical variable name(s). Multiple variable names create small multiples
-#' @param border.lwd line width of the bubble borders. If \code{NA} (default), no bubble borders are drawn.
+#' @param alpha transparency number between 0 (totally transparent) and 1 (not transparent). By default, the alpha value of the \code{col} is used (normally 1).
 #' @param border.col color of the bubble borders.
+#' @param border.lwd line width of the bubble borders. If \code{NA} (default), no bubble borders are drawn.
+#' @param border.alpha transparency number, regarding the bubble borders, between 0 (totally transparent) and 1 (not transparent). By default, the alpha value of the \code{col} is used (normally 1).
 #' @param scale bubble size multiplier number. 
 #' @param size.lim vector of two limit values of the \code{size} variable. Only bubbles are drawn whose value is greater than or equal to the first value. Bubbles whose values exceed the second value are drawn at the size of the second value. Only applicable when \code{size} is the name of a numeric variable of \code{shp}
+#' @param sizes.legend vector of bubble sizes that are shown in the legend. By default, this is determined automatically.
+#' @param sizes.legend.labels vector of labels for that correspond to \code{sizes.legend}.
 #' @param n preferred number of color scale classes. Only applicable when \code{col} is a numeric variable name.
-#' @param style method to cut the color scale: "fixed", "equal", "pretty", "quantile", "kmeans". Only applicable when \code{col} is a numeric variable name.
+#' @param style method to cut the color scale: e.g. "fixed", "equal", "pretty", "quantile", or "kmeans". See the details in \code{\link[classInt:classIntervals]{classIntervals}}. Only applicable when \code{col} is a numeric variable name.
 #' @param breaks in case \code{style=="fixed"}, breaks should be specified
 #' @param palette color palette (see \code{RColorBrewer::display.brewer.all}) for the bubbles. Only when \code{col} is set to a variable.
 #' @param labels labels of the classes
@@ -207,10 +220,14 @@ tm_fill <- function(col="grey90",
 #' @seealso \href{../doc/tmap-nutshell.html}{\code{vignette("tmap-nutshell")}}
 #' @return \code{\link{tmap-element}}
 tm_bubbles <- function(size=1, col="blueviolet",
-						  border.lwd=NA,
-						  border.col="black",
+					      alpha=NA,
+						  border.col=NA,
+					      border.lwd=1,
+					      border.alpha=NA,
 						  scale=1,
 						  size.lim=NA,
+					   	  sizes.legend = NULL,
+					      sizes.legend.labels = NULL,
 						  n = 5, style = "pretty",
 						  breaks = NULL,
 						  palette = NULL,
@@ -222,10 +239,13 @@ tm_bubbles <- function(size=1, col="blueviolet",
 						  textNA = "Missing",
 						  xmod = 0,
 						  ymod = 0) {
-	g <- list(tm_bubbles=list(bubble.size=size, bubble.col=col, bubble.border.lwd=border.lwd,
+	g <- list(tm_bubbles=list(bubble.size=size, bubble.col=col, bubble.alpha=alpha, bubble.border.lwd=border.lwd,
 							   bubble.border.col=border.col,
+							   bubble.border.alpha=border.alpha,
 								 bubble.scale=scale,
 								 size.lim=size.lim,
+							     sizes.legend=sizes.legend,
+							     sizes.legend.labels=sizes.legend.labels,
 								 n=n, style=style, breaks=breaks, palette=palette, labels=labels,
 								 auto.palette.mapping=auto.palette.mapping,
 								 max.categories=max.categories,
@@ -239,40 +259,46 @@ tm_bubbles <- function(size=1, col="blueviolet",
 }
 
 
-#' Small multiples grid
+#' Small multiples
 #' 
-#' This element specifies how small multiples are placed in a grid. Either the argument \code{by} should be specified, i.e. the name of a variable by which the data is grouped, or multiple variable names sould be provided with \code{\link{tm_fill}}, \code{\link{tm_lines}}, or \code{\link{tm_bubbles}}. In this function, the number of rows and columns can be specified, as well as whether the scales are free (i.e. independent of each other).
+#' Creates a \code{\link{tmap-element}} that specifies how small multiples are placed in a facet grid. Either the argument \code{by} should be specified, i.e. the name of a variable by which the data is grouped, or multiple variable names sould be provided with \code{\link{tm_fill}}, \code{\link{tm_lines}}, or \code{\link{tm_bubbles}}. In this function, the number of rows and columns can be specified, as well as whether the scales are free (i.e. independent of each other).
 #' 
 #' @param by data variable name by which the data is split
 #' @param ncol number of columns of the small multiples grid
 #' @param nrow number of rows of the small multiples grid
+#' @param free.coords logical. If the \code{by} argument is specified, should each map has its own coordinate ranges?
+#' @param drop.shapes logical. If the \code{by} argument is specified, should all non-selected shapes be dropped?
 #' @param free.scales logical. Should all scales of the plotted data variables be free, i.e. independent of each other? Possible data variables are color from \code{\link{tm_fill}}, color and size from \code{\link{tm_bubbles}} and line color from \code{\link{tm_lines}}.
 #' @param free.scales.fill logical. Should the color scale for the choropleth be free?
 #' @param free.scales.bubble.size logical. Should the bubble size scale for the bubble map be free?
 #' @param free.scales.bubble.col logical. Should the color scale for the bubble map be free?
 #' @param free.scales.line.col Should the line color scale be free?
 #' @param free.scales.line.lwd Should the line width scale be free?
+#' @param scale.factor Number that determines how the elements (e.g. font sizes, bubble sizes, line widths) of the small multiples are scaled in relation to the scaling factor of the shapes. The elements are scaled to the \code{scale.factor}th root of the scaling factor of the shapes. So, for \code{scale.factor=1}, they are scaled proportional to the scaling of the shapes. Since elements, especially text, are often too small to read, a higher value is recommended. By default, \code{scale.factor=2}.
 #' @export
 #' @example ../examples/tm_facets.R
 #' @seealso \href{../doc/tmap-nutshell.html}{\code{vignette("tmap-nutshell")}}
 #' @return \code{\link{tmap-element}}
 tm_facets <- function(by=NULL, ncol=NULL, nrow=NULL, 
+					   free.coords=FALSE,
+					   drop.shapes=FALSE,
 					   free.scales=is.null(by),
 					   free.scales.fill=free.scales,
 					   free.scales.bubble.size=free.scales,
 					   free.scales.bubble.col=free.scales,
 					   free.scales.line.col=free.scales,
-					   free.scales.line.lwd=free.scales
-					   ) {
-	g <- list(tm_facets=as.list(environment()))
+					   free.scales.line.lwd=free.scales,
+					   scale.factor=2) {
+	g <- list(tm_facets=c(as.list(environment()), list(call=names(match.call(expand.dots = TRUE)[-1]))))
 	class(g) <- "tmap"
-	attr(g, "call") <- names(match.call(expand.dots = TRUE)[-1])
+	#attr(g, "call") <- names(match.call(expand.dots = TRUE)[-1])
+	#g$call <- names(match.call(expand.dots = TRUE)[-1])
 	g
 }
 
 #' Coordinate grid lines
 #' 
-#' This element draws coordinate grid lines.
+#' Creates a \code{\link{tmap-element}} that draws coordinate grid lines.
 #' 
 #' @param n.x Prefered number of grid lines for the x axis.
 #' @param n.y Prefered number of grid lines for the y axis.
